========
tuxsuite
========

---------------------------------------------
TuxSuite helps with Linux kernel development.
---------------------------------------------

:Manual section: 1
:Author: Senthil Kumaran, 2021

SYNOPSIS
========

tuxsuite [OPTIONS] COMMAND [ARGS]...

DESCRIPTION
===========

tuxSuite, by Linaro, is a suite of tools and services to help with
Linux kernel development. The TuxSuite CLI is the supported interface
to TuxBuild and TuxTest. TuxBuild is an on demand API for building
massive quantities of Linux kernels in parallel. TuxTest is an on
demand API for testing Linux kernels reliably and quickly.

OPTIONS
=======

TBA

SEE ALSO
========

The full tuxsuite documentation: <https://docs.tuxsuite.com/>
